@@ -25,7 +25,6 @@
 /**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
 /*****************************************************************************/
 
-
 /**********************************************************************
  *
  * $XConsortium: add_window.h,v 1.7 90/04/17 14:04:33 jim Exp $
@@ -41,22 +40,26 @@
 
 extern char NoName[];
 
-extern TwmWindow *AddWindow();
-extern int MappedNotOverride();
-extern void GrabButtons();
-extern void GrabKeys();
-extern void GrabModKeys();
-extern void UngrabModKeys();
-extern void GetWindowSizeHints();
-extern void FetchWmProtocols();
-extern void FetchWmColormapWindows();
-extern void GetGravityOffsets();
-extern void AddDefaultBindings();
+typedef struct PlaceXY
+{
+  struct PlaceXY *next;
+  int x, y, width, height;
+} PlaceXY;
 
-extern int AddingX;	
+extern int AddingX;
 extern int AddingY;
 extern int AddingW;
 extern int AddingH;
 
 #endif /* _ADD_WINDOW_ */
 
+
+/*
+  Local Variables:
+  mode:c
+  c-file-style:"GNU"
+  c-file-offsets:((substatement-open 0)(brace-list-open 0)(c-hanging-comment-ender-p . nil)(c-hanging-comment-beginner-p . nil)(comment-start . "// ")(comment-end . "")(comment-column . 48))
+  End:
+*/
+/* vim: sw=2
+*/
