@@ -1,3 +1,4 @@
+
 /*
  * $Id: desktop.h,v 3.0 90/11/20 16:13:13 dme Exp Locker: dme $
  *
@@ -17,45 +18,35 @@
  * implied warranty.
  */
 
-extern Window moving_window; /* indicates that we are doing a move in the vd display */
+extern Window moving_window;	/* indicates that we are doing a move in the vd display */
 
-extern void CreateDesktopDisplay();
-extern void UpdateDesktop();
-/* extern void RemoveFromDesktop(); */
-extern void MoveResizeDesktop();
-extern void NailDesktop();
-
-extern void DisplayScreenOnDesktop();
-extern void StartMoveWindowInDesktop();
-extern void StartMoveWindowOnDesktop();
-extern void EndMoveWindowOnDesktop();
-extern void DoMoveWindowOnDesktop();
-extern void ResizeDesktopDisplay();
-extern void VirtualMoveWindow();
-extern void SnapRealScreen();
-extern void SetRealScreen();
-extern void PanRealScreen();
-extern void RaiseStickyAbove(); /* DSE */
-extern void LowerSticky(); /* DSE */
-extern void RaiseAutoPan();
 
 /* convert real space to virtual space */
 #define R_TO_V_X(x) ((x) + Scr->VirtualDesktopX)
 #define R_TO_V_Y(y) ((y) + Scr->VirtualDesktopY)
 
 /* convert virtual space to real space */
-#define V_TO_R_X(x) (-(Scr->VirtualDesktopX - (x)))
-#define V_TO_R_Y(y) (-(Scr->VirtualDesktopY - (y)))
+#define V_TO_R_X(x) ((x) - Scr->VirtualDesktopX)
+#define V_TO_R_Y(y) ((y) - Scr->VirtualDesktopY)
 
 /* scale up and down from desktop display to real sizes */
-/* #define SCALE_D(x) (((x)/Scr->VirtualDesktopDScale)+1) */
+
 /* don't pass me something like `x++' - please */
 #define SCALE_D(x) ((((x)/Scr->VirtualDesktopDScale) < 1) ? 1 : (x)/Scr->VirtualDesktopDScale)
 #define SCALE_U(x) ((x)*Scr->VirtualDesktopDScale)
 
 /* how wide/high the autopan windows are */
-#define AP_SIZE (Scr->AutoPanBorderWidth) /* DSE */
+#define AP_SIZE (Scr->AutoPanBorderWidth)	/* DSE */
 
-/* djhjr - 5/19/98 */
 #define VTWM_DESKTOP_CLASS "VTWM Desktop"
 
+
+/*
+  Local Variables:
+  mode:c
+  c-file-style:"GNU"
+  c-file-offsets:((substatement-open 0)(brace-list-open 0)(c-hanging-comment-ender-p . nil)(c-hanging-comment-beginner-p . nil)(comment-start . "// ")(comment-end . "")(comment-column . 48))
+  End:
+*/
+/* vim: sw=2
+*/
