@@ -1,3 +1,4 @@
+
 /*
  * $Id: doors.h,v 3.0 90/11/20 16:13:19 dme Exp Locker: dme $
  *
@@ -23,40 +24,40 @@
 #include "twm.h"
 
 /* the class of twm doors */
-/* djhjr - 4/27/96
-#define TWM_DOOR_CLASS "Twm Door"
-*/
 #define VTWM_DOOR_CLASS "VTWM Door"
 
 /*
  * the door structure
  */
-typedef struct TwmDoor {
-	struct TwmDoor *next; /* next in the linked list */
-	struct TwmDoor *prev; /* prev in the linked list */
+typedef struct TwmDoor
+{
+  struct TwmDoor *next;		/* next in the linked list */
+  struct TwmDoor *prev;		/* prev in the linked list */
 
-	char *name;           /* name of this door */
-	int x, y;             /* position */
-	int width, height;    /* size */
-	
-	int goto_x, goto_y;   /* destination */
+  char *name;			/* name of this door */
+  int x, y;			/* position */
+  int width, height;		/* size */
 
-	XClassHint *class;     /* name and class of this door */
+  int goto_x, goto_y;		/* destination */
 
-	ColorPair colors;     /* fore and back */
+  XClassHint *class;		/* name and class of this door */
 
-	Window w;             /* the x window for this */
-	TwmWindow *twin;      /* the twmwindow for this */
+  ColorPair colors;		/* fore and back */
+
+  MyWindow w;			/* the x window for this */
+  TwmWindow *twin;		/* the twmwindow for this */
 } TwmDoor;
 
-extern TwmDoor *door_add();
-extern void door_open();
-extern void door_open_all();
-extern void door_enter();
-extern void door_new();
-extern void door_delete();
-
-/* djhjr - 4/20/98 */
-extern void door_paste_name();
 
 #endif /* DOORS_H_INCLUDED */
+
+
+/*
+  Local Variables:
+  mode:c
+  c-file-style:"GNU"
+  c-file-offsets:((substatement-open 0)(brace-list-open 0)(c-hanging-comment-ender-p . nil)(c-hanging-comment-beginner-p . nil)(comment-start . "// ")(comment-end . "")(comment-column . 48))
+  End:
+*/
+/* vim: sw=2
+*/
